MethodChannelCs10Z100PosPrinter class

An implementation of Cs10Z100PosPrinterPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printCheckStatus() Future<PrinterStatus>
override
printClose() Future<bool>
override
printInit() Future<bool>
override
printQrCode(PrinterQrCode qrCode) Future<bool>
override
printStart() Future<bool>
override
printString(PrinterText printerText) Future<bool>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited